Method: Gruff::Base#replace_colors

Defined in:
lib/gruff/base.rb

#replace_colors(color_list = []) ⇒ Object

Replace the entire color list with a new array of colors. Also aliased as the #colors= setter method.

If you specify fewer colors than the number of datasets you intend to draw, it will cycle through the array, reusing colors as needed.

Note that (as with the #theme= method), you should set up your color list before you send your data (via the #data method). Calls to the #data method made prior to this call will use whatever color scheme was in place at the time data was called.

Examples:

replace_colors ['#cc99cc', '#d9e043', '#34d8a2']

Parameters:

  • color_list (Array) (defaults to: [])

    The array of colors.



388
389
390
# File 'lib/gruff/base.rb', line 388

def replace_colors(color_list = [])
  @colors = color_list
end