Method: Gruff::Base#maximum_value
- Defined in:
- lib/gruff/base.rb
#maximum_value ⇒ Float
You can manually set a maximum value, such as a percentage-based graph that always goes to 100.
If you use this, you must set it after you have given all your data to the graph object.
531 532 533 |
# File 'lib/gruff/base.rb', line 531 def maximum_value (@maximum_value || store.max).to_f end |